@@ -7,7 +7,9 @@
    your configure.in uses into your configuration header file templates.
 
    The entries are in sort -df order: alphabetical, case insensitive,
-   ignoring punctuation (such as underscores).
+   ignoring punctuation (such as underscores).  Although this order
+   can split up related entries, it makes it easier to check whether
+   a given entry is in the file.
 
    Leave the following blank line there!!  Autoheader needs it.  */
 
@@ -19,12 +21,19 @@
 #undef _ALL_SOURCE
 #endif
 
+/* Define if using alloca.c.  */
+#undef C_ALLOCA
+
 /* Define if type char is unsigned and you are not using gcc.  */
 #undef __CHAR_UNSIGNED__
 
 /* Define to empty if the keyword does not work.  */
 #undef const
 
+/* Define to one of _getb67, GETB67, getb67 for Cray-2 and Cray-YMP systems.
+   This function is required for alloca.c support on those systems.  */
+#undef CRAY_STACKSEG_END
+
 /* Define as the proper declaration for yytext.  */
 #undef DECLARE_YYTEXT
 
@@ -50,6 +59,9 @@
 /* Define if you don't have vprintf but do have _doprnt.  */
 #undef HAVE_DOPRNT
 
+/* Define if your system has its own `getloadavg' function.  */
+#undef HAVE_GETLOADAVG
+
 /* Define if the `long double' type works.  */
 #undef HAVE_LONG_DOUBLE
 
@@ -109,9 +121,15 @@
 /* Define if you have the POSIX.1 `waitpid' function.  */
 #undef HAVE_WAITPID
 
+/* Define as __inline if that's what the C compiler calls it.  */
+#undef inline
+
 /* Define if int is 16 bits instead of 32.  */
 #undef INT_16_BITS
 
+/* Define if long int is 64 bits.  */
+#undef LONG_64_BITS
+
 /* Define if major, minor, and makedev are declared in mkdev.h.  */
 #undef MAJOR_IN_MKDEV
 
@@ -198,7 +216,10 @@
 /* Define if `sys_siglist' is declared by <signal.h>.  */
 #undef SYS_SIGLIST_DECLARED
 
-/* Define if your sys/time.h declares struct tm.  */
+/* Define if you can safely include both <sys/time.h> and <time.h>.  */
+#undef TIME_WITH_SYS_TIME
+
+/* Define if your <sys/time.h> declares struct tm.  */
 #undef TM_IN_SYS_TIME
 
 /* Define to `int' if <sys/types.h> doesn't define.  */
